@@ -9,9 +9,8 @@ from PyQt5.QtWidgets import QApplication
 
 import urh.cythonext.signal_functions as signal_functions
 from urh.ainterpretation import AutoInterpretation
-
-from urh import constants
 from urh.signalprocessing.Filter import Filter
+from urh.signalprocessing.IQArray import IQArray
 from urh.util import FileOperator
 from urh.util.Logger import logger
 
@@ -23,41 +22,49 @@ class Signal(QObject):
 
     MODULATION_TYPES = ["ASK", "FSK", "PSK", "QAM"]
 
-    bit_len_changed = pyqtSignal(int)
+    samples_per_symbol_changed = pyqtSignal(int)
     tolerance_changed = pyqtSignal(int)
     noise_threshold_changed = pyqtSignal()
-    qad_center_changed = pyqtSignal(float)
+    center_changed = pyqtSignal(float)
+    center_spacing_changed = pyqtSignal(float)
     name_changed = pyqtSignal(str)
     sample_rate_changed = pyqtSignal(float)
-    modulation_type_changed = pyqtSignal(int)
+    modulation_type_changed = pyqtSignal(str)
+    bits_per_symbol_changed = pyqtSignal(int)
 
     saved_status_changed = pyqtSignal()
     protocol_needs_update = pyqtSignal()
     data_edited = pyqtSignal()  # On Crop/Mute/Delete etc.
 
-    def __init__(self, filename: str, name: str, modulation: str = None, sample_rate: float = 1e6, parent=None):
+    def __init__(self, filename: str, name="Signal", modulation: str = None, sample_rate: float = 1e6, parent=None):
         super().__init__(parent)
         self.__name = name
         self.__tolerance = 5
-        self.__bit_len = 100
+        self.__samples_per_symbol = 100
         self.__pause_threshold = 8
         self.__message_length_divisor = 1
+        self.__costas_loop_bandwidth = 0.1
         self._qad = None
-        self.__qad_center = 0
+        self.__center = 0
         self._noise_threshold = 0
         self.__sample_rate = sample_rate
         self.noise_min_plot = 0
         self.noise_max_plot = 0
         self.block_protocol_update = False
 
+        self.iq_array = IQArray(None, np.int8, 1)
+
         self.wav_mode = filename.endswith(".wav")
         self.__changed = False
         if modulation is None:
             modulation = "FSK"
-        self.__modulation_type = self.MODULATION_TYPES.index(modulation)
-        self.__modulation_order = 2
+        self.__modulation_type = modulation
+        self.__bits_per_symbol = 1
+        self.__center_spacing = 1  # required for higher order modulations
 
-        self.__parameter_cache = {mod: {"qad_center": None, "bit_len": None} for mod in self.MODULATION_TYPES}
+        self.__parameter_cache = {mod: {"center": None, "samples_per_symbol": None} for mod in self.MODULATION_TYPES}
+
+        self.__already_demodulated = False
 
         if len(filename) > 0:
             if self.wav_mode:
@@ -68,26 +75,12 @@ class Signal(QObject):
                 self.__load_complex_file(filename)
 
             self.filename = filename
-            self.noise_threshold = AutoInterpretation.detect_noise_level(np.abs(self.data))
+            self.noise_threshold = AutoInterpretation.detect_noise_level(self.iq_array.magnitudes)
         else:
             self.filename = ""
 
     def __load_complex_file(self, filename: str):
-        if filename.endswith(".complex16u") or filename.endswith(".cu8"):
-            # two 8 bit unsigned integers
-            raw = np.fromfile(filename, dtype=[('r', np.uint8), ('i', np.uint8)])
-            self._fulldata = np.empty(raw.shape[0], dtype=np.complex64)
-            self._fulldata.real = (raw['r'] / 127.5) - 1.0
-            self._fulldata.imag = (raw['i'] / 127.5) - 1.0
-        elif filename.endswith(".complex16s") or filename.endswith(".cs8"):
-            # two 8 bit signed integers
-            raw = np.fromfile(filename, dtype=[('r', np.int8), ('i', np.int8)])
-            self._fulldata = np.empty(raw.shape[0], dtype=np.complex64)
-            self._fulldata.real = (raw['r'] + 0.5) / 127.5
-            self._fulldata.imag = (raw['i'] + 0.5) / 127.5
-        else:
-            # Uncompressed
-            self._fulldata = np.fromfile(filename, dtype=np.complex64)
+        self.iq_array = IQArray.from_file(filename)
 
     def __load_wav_file(self, filename: str):
         wav = wave.open(filename, "r")
@@ -117,13 +110,13 @@ class Signal(QObject):
         else:
             data = np.frombuffer(byte_frames, dtype=params["fmt"])
 
+        self.iq_array = IQArray(None, np.float32, n=num_frames)
         if num_channels == 1:
-            self._fulldata = np.zeros(num_frames, dtype=np.complex64, order="C")
-            self._fulldata.real = np.multiply(1 / params["max"], np.subtract(data, params["center"]))
+            self.iq_array.real = np.multiply(1 / params["max"], np.subtract(data, params["center"]))
+            self.__already_demodulated = True
         elif num_channels == 2:
-            self._fulldata = np.zeros(num_frames, dtype=np.complex64, order="C")
-            self._fulldata.real = np.multiply(1 / params["max"], np.subtract(data[0::2], params["center"]))
-            self._fulldata.imag = np.multiply(1 / params["max"], np.subtract(data[1::2], params["center"]))
+            self.iq_array.real = np.multiply(1 / params["max"], np.subtract(data[0::2], params["center"]))
+            self.iq_array.imag = np.multiply(1 / params["max"], np.subtract(data[1::2], params["center"]))
         else:
             raise ValueError("Can't handle {0} channels. Only 1 and 2 are supported.".format(num_channels))
 
@@ -136,9 +129,13 @@ class Signal(QObject):
         members = obj.getmembers()
         obj.extract(members[0], QDir.tempPath())
         extracted_filename = os.path.join(QDir.tempPath(), obj.getnames()[0])
-        self._fulldata = np.fromfile(extracted_filename, dtype=np.complex64)
+        self.__load_complex_file(extracted_filename)
         os.remove(extracted_filename)
 
+    @property
+    def already_demodulated(self) -> bool:
+        return self.__already_demodulated
+
     @property
     def sample_rate(self):
         return self.__sample_rate
@@ -152,7 +149,7 @@ class Signal(QObject):
     @property
     def parameter_cache(self) -> dict:
         """
-        Caching bit_len and qad_center for modulations, so they do not need
+        Caching bit_len and center for modulations, so they do not need
         to be recalculated every time.
 
         :return:
@@ -164,17 +161,11 @@ class Signal(QObject):
         self.__parameter_cache = val
 
     @property
-    def modulation_type(self):
+    def modulation_type(self) -> str:
         return self.__modulation_type
 
     @modulation_type.setter
-    def modulation_type(self, value: int):
-        """
-        0 - "ASK", 1 - "FSK", 2 - "PSK", 3 - "APSK (QAM)"
-
-        :param value:
-        :return:
-        """
+    def modulation_type(self, value: str):
         if self.__modulation_type != value:
             self.__modulation_type = value
             self._qad = None
@@ -184,31 +175,42 @@ class Signal(QObject):
                 self.protocol_needs_update.emit()
 
     @property
-    def modulation_type_str(self):
-        return self.MODULATION_TYPES[self.modulation_type]
+    def bits_per_symbol(self):
+        return self.__bits_per_symbol
 
-    @modulation_type_str.setter
-    def modulation_type_str(self, value: str):
-        self.modulation_type = self.MODULATION_TYPES.index(value)
+    @bits_per_symbol.setter
+    def bits_per_symbol(self, value: int):
+        if self.__bits_per_symbol != value:
+            self.__bits_per_symbol = int(value)
+            self._qad = None
 
-    @property
-    def bit_len(self):
-        return self.__bit_len
-
-    @bit_len.setter
-    def bit_len(self, value):
-        if self.__bit_len != value:
-            self.__bit_len = value
-            self.bit_len_changed.emit(value)
+            self.bits_per_symbol_changed.emit(self.__bits_per_symbol)
             if not self.block_protocol_update:
                 self.protocol_needs_update.emit()
 
+    @property
+    def samples_per_symbol(self):
+        return self.__samples_per_symbol
+
+    @samples_per_symbol.setter
+    def samples_per_symbol(self, value):
+        if self.__samples_per_symbol != value:
+            self.__samples_per_symbol = value
+            self.samples_per_symbol_changed.emit(value)
+            if not self.block_protocol_update:
+                self.protocol_needs_update.emit()
+
+    @property
+    def modulation_order(self):
+        return 2 ** self.bits_per_symbol
+
     @property
     def tolerance(self):
         return self.__tolerance
 
     @tolerance.setter
     def tolerance(self, value):
+        value = int(value)
         if self.__tolerance != value:
             self.__tolerance = value
             self.tolerance_changed.emit(value)
@@ -216,17 +218,33 @@ class Signal(QObject):
                 self.protocol_needs_update.emit()
 
     @property
-    def qad_center(self):
-        return self.__qad_center
+    def center(self):
+        return self.__center
 
-    @qad_center.setter
-    def qad_center(self, value: float):
-        if self.__qad_center != value:
-            self.__qad_center = value
-            self.qad_center_changed.emit(value)
+    @center.setter
+    def center(self, value: float):
+        if self.__center != value:
+            self.__center = value
+            self.center_changed.emit(value)
             if not self.block_protocol_update:
                 self.protocol_needs_update.emit()
 
+    @property
+    def center_spacing(self) -> float:
+        return self.__center_spacing
+
+    @center_spacing.setter
+    def center_spacing(self, value: float):
+        if self.__center_spacing != value:
+            self.__center_spacing = value
+            self.center_spacing_changed.emit(value)
+            if not self.block_protocol_update:
+                self.protocol_needs_update.emit()
+
+    @property
+    def center_thresholds(self):
+        return self.get_thresholds_for_center(self.center)
+
     @property
     def pause_threshold(self) -> int:
         return self.__pause_threshold
@@ -238,6 +256,18 @@ class Signal(QObject):
             if not self.block_protocol_update:
                 self.protocol_needs_update.emit()
 
+    @property
+    def costas_loop_bandwidth(self):
+        return self.__costas_loop_bandwidth
+
+    @costas_loop_bandwidth.setter
+    def costas_loop_bandwidth(self, value: float):
+        if self.__costas_loop_bandwidth != value:
+            self.__costas_loop_bandwidth = value
+            self._qad = None
+            if not self.block_protocol_update:
+                self.protocol_needs_update.emit()
+
     @property
     def message_length_divisor(self) -> int:
         return self.__message_length_divisor
@@ -261,7 +291,7 @@ class Signal(QObject):
 
     @property
     def num_samples(self):
-        return len(self.data)
+        return self.iq_array.num_samples
 
     @property
     def noise_threshold(self):
@@ -273,34 +303,50 @@ class Signal(QObject):
             self._qad = None
             self.clear_parameter_cache()
             self._noise_threshold = value
-            self.noise_min_plot = -value
-            self.noise_max_plot = value
+
+            middle = 0.5*sum(IQArray.min_max_for_dtype(self.iq_array.dtype))
+            a = self.max_amplitude * value / self.max_magnitude
+            self.noise_min_plot = middle - a
+            self.noise_max_plot = middle + a
             self.noise_threshold_changed.emit()
             if not self.block_protocol_update:
                 self.protocol_needs_update.emit()
 
+    @property
+    def max_magnitude(self):
+        mi, ma = IQArray.min_max_for_dtype(self.iq_array.dtype)
+        return (2 * max(mi**2, ma**2))**0.5
+
+    @property
+    def max_amplitude(self):
+        mi, ma = IQArray.min_max_for_dtype(self.iq_array.dtype)
+        return 0.5 * (ma - mi)
+
+    @property
+    def noise_threshold_relative(self):
+        return self.noise_threshold / self.max_magnitude
+
+    @noise_threshold_relative.setter
+    def noise_threshold_relative(self, value: float):
+        self.noise_threshold = value * self.max_magnitude
+
     @property
     def qad(self):
         if self._qad is None:
-            self._qad = self.quad_demod()
+            if self.already_demodulated:
+                self._qad = np.ascontiguousarray(self.real_plot_data, dtype=self.real_plot_data.dtype)
+            else:
+                self._qad = self.quad_demod()
 
         return self._qad
 
-    @property
-    def data(self) -> np.ndarray:
-        return self._fulldata
-
     @property
     def real_plot_data(self):
         try:
-            return self.data.real
+            return self.iq_array.real
         except AttributeError:
             return np.zeros(0, dtype=np.float32)
 
-    @property
-    def wave_data(self):
-        return (self.data.view(np.float32) * 32767).astype(np.int16)
-
     @property
     def changed(self) -> bool:
         """
@@ -328,20 +374,12 @@ class Signal(QObject):
         self.changed = False
         QApplication.instance().restoreOverrideCursor()
 
-    def get_signal_start(self) -> int:
-        """
-        Index ab dem das Signal losgeht (Nach Übersteuern + Pause am Anfang)
-
-        """
-        return signal_functions.find_signal_start(self.qad, self.modulation_type)
-
-    def get_signal_end(self):
-        return signal_functions.find_signal_end(self.qad, self.modulation_type)
-
     def quad_demod(self):
-        return signal_functions.afp_demod(self.data, self.noise_threshold, self.modulation_type)
+        return signal_functions.afp_demod(self.iq_array.data, self.noise_threshold,
+                                          self.modulation_type, self.modulation_order,
+                                          self.costas_loop_bandwidth)
 
-    def calc_noise_threshold(self, noise_start: int, noise_end: int):
+    def calc_relative_noise_threshold_from_range(self, noise_start: int, noise_end: int):
         num_digits = 4
         noise_start, noise_end = int(noise_start), int(noise_end)
 
@@ -349,36 +387,42 @@ class Signal(QObject):
             noise_start, noise_end = noise_end, noise_start
 
         try:
-            magnitudes = np.absolute(self.data[noise_start:noise_end])
-            maximum = np.max(magnitudes)
+            maximum = np.max(self.iq_array.subarray(noise_start, noise_end).magnitudes_normalized)
             return np.ceil(maximum * 10 ** num_digits) / 10 ** num_digits
         except ValueError:
             logger.warning("Could not calculate noise threshold for range {}-{}".format(noise_start, noise_end))
-            return self.noise_threshold
+            return self.noise_threshold_relative
 
     def create_new(self, start=0, end=0, new_data=None):
         new_signal = Signal("", "New " + self.name)
 
         if new_data is None:
-            new_signal._fulldata = self.data[start:end]
+            new_signal.iq_array = IQArray(self.iq_array[start:end])
         else:
-            new_signal._fulldata = new_data
+            new_signal.iq_array = IQArray(new_data)
 
         new_signal._noise_threshold = self.noise_threshold
         new_signal.noise_min_plot = self.noise_min_plot
         new_signal.noise_max_plot = self.noise_max_plot
-        new_signal.__bit_len = self.bit_len
-        new_signal.__qad_center = self.qad_center
+        new_signal.__samples_per_symbol = self.samples_per_symbol
+        new_signal.__bits_per_symbol = self.bits_per_symbol
+        new_signal.__center = self.center
+        new_signal.wav_mode = self.wav_mode
+        new_signal.__already_demodulated = self.__already_demodulated
         new_signal.changed = True
         return new_signal
 
+    def get_thresholds_for_center(self, center: float, spacing=None):
+        spacing = self.center_spacing if spacing is None else spacing
+        return signal_functions.get_center_thresholds(center, spacing, self.modulation_order)
+
     def auto_detect(self, emit_update=True, detect_modulation=True, detect_noise=False) -> bool:
         kwargs = {"noise": None if detect_noise else self.noise_threshold,
                   "modulation": None if detect_modulation
-                  else "OOK" if self.__modulation_order == 2 and self.__modulation_type == 0
-                  else self.modulation_type_str}
+                  else "OOK" if self.bits_per_symbol == 1 and self.modulation_type == "ASK"
+                  else self.modulation_type}
 
-        estimated_params = AutoInterpretation.estimate(self.data, **kwargs)
+        estimated_params = AutoInterpretation.estimate(self.iq_array, **kwargs)
         if estimated_params is None:
             return False
 
@@ -389,11 +433,11 @@ class Signal(QObject):
             self.noise_threshold = estimated_params["noise"]
 
         if detect_modulation:
-            self.modulation_type_str = estimated_params["modulation_type"]
+            self.modulation_type = estimated_params["modulation_type"]
 
-        self.qad_center = estimated_params["center"]
+        self.center = estimated_params["center"]
         self.tolerance = estimated_params["tolerance"]
-        self.bit_len = estimated_params["bit_length"]
+        self.samples_per_symbol = estimated_params["bit_length"]
 
         self.block_protocol_update = orig_block
 
@@ -404,8 +448,8 @@ class Signal(QObject):
 
     def clear_parameter_cache(self):
         for mod in self.parameter_cache.keys():
-            self.parameter_cache[mod]["bit_len"] = None
-            self.parameter_cache[mod]["qad_center"] = None
+            self.parameter_cache[mod]["samples_per_symbol"] = None
+            self.parameter_cache[mod]["center"] = None
 
     def estimate_frequency(self, start: int, end: int, sample_rate: float):
         """
@@ -418,7 +462,7 @@ class Signal(QObject):
         """
         # ensure power of 2 for faster fft
         length = 2 ** int(math.log2(end - start))
-        data = self.data[start:start + length]
+        data = self.iq_array.as_complex64()[start:start + length]
 
         try:
             w = np.fft.fft(data)
@@ -433,15 +477,15 @@ class Signal(QObject):
         return freq_in_hertz
 
     def eliminate(self):
-        self._fulldata = None
+        self.iq_array = None
         self._qad = None
         self.parameter_cache.clear()
 
-    def silent_set_modulation_type(self, mod_type: int):
+    def silent_set_modulation_type(self, mod_type: str):
         self.__modulation_type = mod_type
 
     def insert_data(self, index: int, data: np.ndarray):
-        self._fulldata = np.insert(self._fulldata, index, data)
+        self.iq_array.insert_subarray(index, data)
         self._qad = None
 
         self.__invalidate_after_edit()
@@ -451,7 +495,7 @@ class Signal(QObject):
         mask[start:end] = False
 
         try:
-            self._fulldata = self._fulldata[mask]
+            self.iq_array.apply_mask(mask)
             self._qad = self._qad[mask] if self._qad is not None else None
         except IndexError as e:
             logger.warning("Could not delete data: " + str(e))
@@ -459,22 +503,25 @@ class Signal(QObject):
         self.__invalidate_after_edit()
 
     def mute_range(self, start: int, end: int):
-        self._fulldata[start:end] = 0
+        self.iq_array[start:end] = 0
         if self._qad is not None:
             self._qad[start:end] = 0
 
         self.__invalidate_after_edit()
 
     def crop_to_range(self, start: int, end: int):
-        self._fulldata = self._fulldata[start:end]
+        self.iq_array = IQArray(self.iq_array[start:end])
         self._qad = self._qad[start:end] if self._qad is not None else None
 
         self.__invalidate_after_edit()
 
     def filter_range(self, start: int, end: int, fir_filter: Filter):
-        self._fulldata[start:end] = fir_filter.work(self._fulldata[start:end])
-        self._qad[start:end] = signal_functions.afp_demod(self.data[start:end],
-                                                          self.noise_threshold, self.modulation_type)
+        self.iq_array[start:end] = fir_filter.work(self.iq_array[start:end])
+        self._qad[start:end] = signal_functions.afp_demod(self.iq_array[start:end],
+                                                          self.noise_threshold,
+                                                          self.modulation_type,
+                                                          self.modulation_order,
+                                                          self.costas_loop_bandwidth)
         self.__invalidate_after_edit()
 
     def __invalidate_after_edit(self):
@@ -486,6 +533,6 @@ class Signal(QObject):
     @staticmethod
     def from_samples(samples: np.ndarray, name: str, sample_rate: float):
         signal = Signal("", name, sample_rate=sample_rate)
-        signal._fulldata = samples
+        signal.iq_array = IQArray(samples)
 
         return signal
