@@ -4,12 +4,14 @@
 #
 # WARNING! All changes made in this file will be lost!
 
+
 from PyQt5 import QtCore, QtGui, QtWidgets
 
+
 class Ui_TabAnalysis(object):
     def setupUi(self, TabAnalysis):
         TabAnalysis.setObjectName("TabAnalysis")
-        TabAnalysis.resize(1331, 740)
+        TabAnalysis.resize(1331, 739)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -30,7 +32,7 @@ class Ui_TabAnalysis(object):
         self.scrollArea.setWidgetResizable(True)
         self.scrollArea.setObjectName("scrollArea")
         self.scrollAreaWidgetContents = QtWidgets.QWidget()
-        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 1331, 740))
+        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 1331, 739))
         self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
         self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
         self.verticalLayout_5.setObjectName("verticalLayout_5")
@@ -73,7 +75,7 @@ class Ui_TabAnalysis(object):
         self.verticalLayout_3.setSpacing(7)
         self.verticalLayout_3.setObjectName("verticalLayout_3")
         self.treeViewProtocols = ProtocolTreeView(self.tab_protocols)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.treeViewProtocols.sizePolicy().hasHeightForWidth())
@@ -113,36 +115,22 @@ class Ui_TabAnalysis(object):
         self.verticalLayout_11.addWidget(self.listViewParticipants)
         self.tabWidget.addTab(self.tab_participants, "")
         self.verticalLayout_2.addWidget(self.tabWidget)
-        self.line_3 = QtWidgets.QFrame(self.layoutWidget)
-        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
-        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
-        self.line_3.setObjectName("line_3")
-        self.verticalLayout_2.addWidget(self.line_3)
+        self.gridLayout_3 = QtWidgets.QGridLayout()
+        self.gridLayout_3.setObjectName("gridLayout_3")
+        self.label_5 = QtWidgets.QLabel(self.layoutWidget)
+        self.label_5.setObjectName("label_5")
+        self.gridLayout_3.addWidget(self.label_5, 1, 0, 1, 1)
         self.label_4 = QtWidgets.QLabel(self.layoutWidget)
-        font = QtGui.QFont()
-        font.setBold(True)
-        font.setWeight(75)
-        self.label_4.setFont(font)
         self.label_4.setObjectName("label_4")
-        self.verticalLayout_2.addWidget(self.label_4)
-        self.cbProtoView = QtWidgets.QComboBox(self.layoutWidget)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
+        self.gridLayout_3.addWidget(self.label_4, 0, 0, 1, 1)
+        self.lEncodingErrors = QtWidgets.QLabel(self.layoutWidget)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
-        sizePolicy.setHeightForWidth(self.cbProtoView.sizePolicy().hasHeightForWidth())
-        self.cbProtoView.setSizePolicy(sizePolicy)
-        self.cbProtoView.setObjectName("cbProtoView")
-        self.cbProtoView.addItem("")
-        self.cbProtoView.addItem("")
-        self.cbProtoView.addItem("")
-        self.verticalLayout_2.addWidget(self.cbProtoView)
-        self.label_5 = QtWidgets.QLabel(self.layoutWidget)
-        font = QtGui.QFont()
-        font.setBold(True)
-        font.setWeight(75)
-        self.label_5.setFont(font)
-        self.label_5.setObjectName("label_5")
-        self.verticalLayout_2.addWidget(self.label_5)
+        sizePolicy.setHeightForWidth(self.lEncodingErrors.sizePolicy().hasHeightForWidth())
+        self.lEncodingErrors.setSizePolicy(sizePolicy)
+        self.lEncodingErrors.setObjectName("lEncodingErrors")
+        self.gridLayout_3.addWidget(self.lEncodingErrors, 2, 0, 1, 1)
         self.cbDecoding = QtWidgets.QComboBox(self.layoutWidget)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
         sizePolicy.setHorizontalStretch(0)
@@ -156,43 +144,50 @@ class Ui_TabAnalysis(object):
         self.cbDecoding.addItem("")
         self.cbDecoding.addItem("")
         self.cbDecoding.addItem("")
-        self.verticalLayout_2.addWidget(self.cbDecoding)
-        self.lEncodingErrors = QtWidgets.QLabel(self.layoutWidget)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
+        self.gridLayout_3.addWidget(self.cbDecoding, 1, 1, 1, 1)
+        self.chkBoxShowOnlyDiffs = QtWidgets.QCheckBox(self.layoutWidget)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
-        sizePolicy.setHeightForWidth(self.lEncodingErrors.sizePolicy().hasHeightForWidth())
-        self.lEncodingErrors.setSizePolicy(sizePolicy)
-        font = QtGui.QFont()
-        font.setBold(True)
-        font.setWeight(75)
-        self.lEncodingErrors.setFont(font)
-        self.lEncodingErrors.setObjectName("lEncodingErrors")
-        self.verticalLayout_2.addWidget(self.lEncodingErrors)
+        sizePolicy.setHeightForWidth(self.chkBoxShowOnlyDiffs.sizePolicy().hasHeightForWidth())
+        self.chkBoxShowOnlyDiffs.setSizePolicy(sizePolicy)
+        self.chkBoxShowOnlyDiffs.setObjectName("chkBoxShowOnlyDiffs")
+        self.gridLayout_3.addWidget(self.chkBoxShowOnlyDiffs, 4, 0, 1, 2)
+        self.cbProtoView = QtWidgets.QComboBox(self.layoutWidget)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
+        sizePolicy.setHorizontalStretch(0)
+        sizePolicy.setVerticalStretch(0)
+        sizePolicy.setHeightForWidth(self.cbProtoView.sizePolicy().hasHeightForWidth())
+        self.cbProtoView.setSizePolicy(sizePolicy)
+        self.cbProtoView.setObjectName("cbProtoView")
+        self.cbProtoView.addItem("")
+        self.cbProtoView.addItem("")
+        self.cbProtoView.addItem("")
+        self.gridLayout_3.addWidget(self.cbProtoView, 0, 1, 1, 1)
         self.lDecodingErrorsValue = QtWidgets.QLabel(self.layoutWidget)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.lDecodingErrorsValue.sizePolicy().hasHeightForWidth())
         self.lDecodingErrorsValue.setSizePolicy(sizePolicy)
         self.lDecodingErrorsValue.setObjectName("lDecodingErrorsValue")
-        self.verticalLayout_2.addWidget(self.lDecodingErrorsValue)
-        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
-        self.verticalLayout_2.addItem(spacerItem)
+        self.gridLayout_3.addWidget(self.lDecodingErrorsValue, 2, 1, 1, 1)
+        self.chkBoxOnlyShowLabelsInProtocol = QtWidgets.QCheckBox(self.layoutWidget)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
+        sizePolicy.setHorizontalStretch(0)
+        sizePolicy.setVerticalStretch(0)
+        sizePolicy.setHeightForWidth(self.chkBoxOnlyShowLabelsInProtocol.sizePolicy().hasHeightForWidth())
+        self.chkBoxOnlyShowLabelsInProtocol.setSizePolicy(sizePolicy)
+        self.chkBoxOnlyShowLabelsInProtocol.setObjectName("chkBoxOnlyShowLabelsInProtocol")
+        self.gridLayout_3.addWidget(self.chkBoxOnlyShowLabelsInProtocol, 5, 0, 1, 2)
         self.cbShowDiffs = QtWidgets.QCheckBox(self.layoutWidget)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.cbShowDiffs.sizePolicy().hasHeightForWidth())
         self.cbShowDiffs.setSizePolicy(sizePolicy)
         self.cbShowDiffs.setObjectName("cbShowDiffs")
-        self.verticalLayout_2.addWidget(self.cbShowDiffs)
-        self.chkBoxShowOnlyDiffs = QtWidgets.QCheckBox(self.layoutWidget)
-        self.chkBoxShowOnlyDiffs.setObjectName("chkBoxShowOnlyDiffs")
-        self.verticalLayout_2.addWidget(self.chkBoxShowOnlyDiffs)
-        self.chkBoxOnlyShowLabelsInProtocol = QtWidgets.QCheckBox(self.layoutWidget)
-        self.chkBoxOnlyShowLabelsInProtocol.setObjectName("chkBoxOnlyShowLabelsInProtocol")
-        self.verticalLayout_2.addWidget(self.chkBoxOnlyShowLabelsInProtocol)
+        self.gridLayout_3.addWidget(self.cbShowDiffs, 3, 0, 1, 2)
         self.stackedWidgetLogicAnalysis = QtWidgets.QStackedWidget(self.layoutWidget)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
         sizePolicy.setHorizontalStretch(0)
@@ -233,7 +228,8 @@ class Ui_TabAnalysis(object):
         self.progressBarLogicAnalyzer.setObjectName("progressBarLogicAnalyzer")
         self.verticalLayout_9.addWidget(self.progressBarLogicAnalyzer)
         self.stackedWidgetLogicAnalysis.addWidget(self.pageProgressBar)
-        self.verticalLayout_2.addWidget(self.stackedWidgetLogicAnalysis)
+        self.gridLayout_3.addWidget(self.stackedWidgetLogicAnalysis, 6, 0, 1, 2)
+        self.verticalLayout_2.addLayout(self.gridLayout_3)
         self.layoutWidget1 = QtWidgets.QWidget(self.splitter)
         self.layoutWidget1.setObjectName("layoutWidget1")
         self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget1)
@@ -253,10 +249,7 @@ class Ui_TabAnalysis(object):
         self.btnSaveProto.setIcon(icon)
         self.btnSaveProto.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
         self.btnSaveProto.setObjectName("btnSaveProto")
-        self.gridLayout_2.addWidget(self.btnSaveProto, 0, 17, 1, 1)
-        self.label_2 = QtWidgets.QLabel(self.layoutWidget1)
-        self.label_2.setObjectName("label_2")
-        self.gridLayout_2.addWidget(self.label_2, 0, 12, 1, 1)
+        self.gridLayout_2.addWidget(self.btnSaveProto, 0, 16, 1, 1)
         self.lSlash = QtWidgets.QLabel(self.layoutWidget1)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
@@ -278,7 +271,7 @@ class Ui_TabAnalysis(object):
         self.lTime.setTextFormat(QtCore.Qt.PlainText)
         self.lTime.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
         self.lTime.setObjectName("lTime")
-        self.gridLayout_2.addWidget(self.lTime, 0, 16, 1, 1)
+        self.gridLayout_2.addWidget(self.lTime, 0, 15, 1, 1)
         self.lSearchCurrent = QtWidgets.QLabel(self.layoutWidget1)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
@@ -298,17 +291,7 @@ class Ui_TabAnalysis(object):
         sizePolicy.setHeightForWidth(self.lblRSSI.sizePolicy().hasHeightForWidth())
         self.lblRSSI.setSizePolicy(sizePolicy)
         self.lblRSSI.setObjectName("lblRSSI")
-        self.gridLayout_2.addWidget(self.lblRSSI, 0, 13, 1, 1)
-        self.lineEditSearch = QtWidgets.QLineEdit(self.layoutWidget1)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
-        sizePolicy.setHorizontalStretch(0)
-        sizePolicy.setVerticalStretch(0)
-        sizePolicy.setHeightForWidth(self.lineEditSearch.sizePolicy().hasHeightForWidth())
-        self.lineEditSearch.setSizePolicy(sizePolicy)
-        self.lineEditSearch.setAcceptDrops(False)
-        self.lineEditSearch.setClearButtonEnabled(True)
-        self.lineEditSearch.setObjectName("lineEditSearch")
-        self.gridLayout_2.addWidget(self.lineEditSearch, 0, 1, 1, 1)
+        self.gridLayout_2.addWidget(self.lblRSSI, 0, 12, 1, 1)
         self.btnNextSearch = QtWidgets.QToolButton(self.layoutWidget1)
         self.btnNextSearch.setEnabled(False)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
@@ -346,12 +329,12 @@ class Ui_TabAnalysis(object):
         self.label_3 = QtWidgets.QLabel(self.layoutWidget1)
         self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
         self.label_3.setObjectName("label_3")
-        self.gridLayout_2.addWidget(self.label_3, 0, 15, 1, 1)
+        self.gridLayout_2.addWidget(self.label_3, 0, 14, 1, 1)
         self.line_2 = QtWidgets.QFrame(self.layoutWidget1)
         self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
         self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
         self.line_2.setObjectName("line_2")
-        self.gridLayout_2.addWidget(self.line_2, 0, 14, 1, 1)
+        self.gridLayout_2.addWidget(self.line_2, 0, 13, 1, 1)
         self.btnSearchSelectFilter = QtWidgets.QToolButton(self.layoutWidget1)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
@@ -366,8 +349,8 @@ class Ui_TabAnalysis(object):
         self.btnSearchSelectFilter.setArrowType(QtCore.Qt.NoArrow)
         self.btnSearchSelectFilter.setObjectName("btnSearchSelectFilter")
         self.gridLayout_2.addWidget(self.btnSearchSelectFilter, 0, 2, 1, 1)
-        spacerItem1 = QtWidgets.QSpacerItem(60, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
-        self.gridLayout_2.addItem(spacerItem1, 0, 10, 1, 1)
+        spacerItem = QtWidgets.QSpacerItem(60, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
+        self.gridLayout_2.addItem(spacerItem, 0, 10, 1, 1)
         self.line = QtWidgets.QFrame(self.layoutWidget1)
         self.line.setFrameShape(QtWidgets.QFrame.VLine)
         self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
@@ -382,10 +365,20 @@ class Ui_TabAnalysis(object):
         icon = QtGui.QIcon.fromTheme("document-open")
         self.btnLoadProto.setIcon(icon)
         self.btnLoadProto.setObjectName("btnLoadProto")
-        self.gridLayout_2.addWidget(self.btnLoadProto, 0, 18, 1, 1)
+        self.gridLayout_2.addWidget(self.btnLoadProto, 0, 17, 1, 1)
         self.lblClearAlignment = QtWidgets.QLabel(self.layoutWidget1)
         self.lblClearAlignment.setObjectName("lblClearAlignment")
         self.gridLayout_2.addWidget(self.lblClearAlignment, 0, 3, 1, 1)
+        self.lineEditSearch = QtWidgets.QLineEdit(self.layoutWidget1)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
+        sizePolicy.setHorizontalStretch(0)
+        sizePolicy.setVerticalStretch(0)
+        sizePolicy.setHeightForWidth(self.lineEditSearch.sizePolicy().hasHeightForWidth())
+        self.lineEditSearch.setSizePolicy(sizePolicy)
+        self.lineEditSearch.setAcceptDrops(False)
+        self.lineEditSearch.setClearButtonEnabled(True)
+        self.lineEditSearch.setObjectName("lineEditSearch")
+        self.gridLayout_2.addWidget(self.lineEditSearch, 0, 1, 1, 1)
         self.verticalLayout.addLayout(self.gridLayout_2)
         self.tblViewProtocol = ProtocolTableView(self.layoutWidget1)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
@@ -411,7 +404,7 @@ class Ui_TabAnalysis(object):
         self.tblViewProtocol.setWordWrap(False)
         self.tblViewProtocol.setCornerButtonEnabled(False)
         self.tblViewProtocol.setObjectName("tblViewProtocol")
-        self.tblViewProtocol.horizontalHeader().setDefaultSectionSize(40)
+        self.tblViewProtocol.horizontalHeader().setDefaultSectionSize(57)
         self.verticalLayout.addWidget(self.tblViewProtocol)
         self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
         self.horizontalLayout_3.setObjectName("horizontalLayout_3")
@@ -432,6 +425,8 @@ class Ui_TabAnalysis(object):
         self.lBitsSelection.setSizePolicy(sizePolicy)
         self.lBitsSelection.setMaximumSize(QtCore.QSize(16777215, 16777215))
         self.lBitsSelection.setAcceptDrops(False)
+        self.lBitsSelection.setStyleSheet("background-color: rgba(255, 255, 255, 0);")
+        self.lBitsSelection.setFrame(False)
         self.lBitsSelection.setReadOnly(True)
         self.lBitsSelection.setObjectName("lBitsSelection")
         self.horizontalLayout_3.addWidget(self.lBitsSelection)
@@ -452,6 +447,8 @@ class Ui_TabAnalysis(object):
         self.lHexSelection.setSizePolicy(sizePolicy)
         self.lHexSelection.setMaximumSize(QtCore.QSize(16777215, 16777215))
         self.lHexSelection.setAcceptDrops(False)
+        self.lHexSelection.setStyleSheet("background-color: rgba(255, 255, 255, 0);")
+        self.lHexSelection.setFrame(False)
         self.lHexSelection.setReadOnly(True)
         self.lHexSelection.setObjectName("lHexSelection")
         self.horizontalLayout_3.addWidget(self.lHexSelection)
@@ -472,6 +469,8 @@ class Ui_TabAnalysis(object):
         self.lDecimalSelection.setSizePolicy(sizePolicy)
         self.lDecimalSelection.setMaximumSize(QtCore.QSize(16777215, 16777215))
         self.lDecimalSelection.setAcceptDrops(False)
+        self.lDecimalSelection.setStyleSheet("background-color: rgba(255, 255, 255, 0);")
+        self.lDecimalSelection.setFrame(False)
         self.lDecimalSelection.setReadOnly(True)
         self.lDecimalSelection.setObjectName("lDecimalSelection")
         self.horizontalLayout_3.addWidget(self.lDecimalSelection)
@@ -495,37 +494,35 @@ class Ui_TabAnalysis(object):
         self.verticalLayout_4.setObjectName("verticalLayout_4")
         self.gridLayout = QtWidgets.QGridLayout()
         self.gridLayout.setObjectName("gridLayout")
-        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
-        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
-        self.cbMessagetypes = QtWidgets.QComboBox(self.layoutWidget2)
-        self.cbMessagetypes.setEditable(True)
-        self.cbMessagetypes.setInsertPolicy(QtWidgets.QComboBox.NoInsert)
-        self.cbMessagetypes.setObjectName("cbMessagetypes")
-        self.horizontalLayout_2.addWidget(self.cbMessagetypes)
-        self.btnMessagetypeSettings = QtWidgets.QToolButton(self.layoutWidget2)
-        icon = QtGui.QIcon.fromTheme("preferences-other")
-        self.btnMessagetypeSettings.setIcon(icon)
-        self.btnMessagetypeSettings.setObjectName("btnMessagetypeSettings")
-        self.horizontalLayout_2.addWidget(self.btnMessagetypeSettings)
-        self.btnAddMessagetype = QtWidgets.QToolButton(self.layoutWidget2)
-        icon = QtGui.QIcon.fromTheme("list-add")
-        self.btnAddMessagetype.setIcon(icon)
-        self.btnAddMessagetype.setObjectName("btnAddMessagetype")
-        self.horizontalLayout_2.addWidget(self.btnAddMessagetype)
-        self.btnRemoveMessagetype = QtWidgets.QToolButton(self.layoutWidget2)
-        icon = QtGui.QIcon.fromTheme("list-remove")
-        self.btnRemoveMessagetype.setIcon(icon)
-        self.btnRemoveMessagetype.setObjectName("btnRemoveMessagetype")
-        self.horizontalLayout_2.addWidget(self.btnRemoveMessagetype)
-        self.gridLayout.addLayout(self.horizontalLayout_2, 1, 0, 1, 1)
         self.label = QtWidgets.QLabel(self.layoutWidget2)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
         self.label.setSizePolicy(sizePolicy)
+        self.label.setAlignment(QtCore.Qt.AlignCenter)
         self.label.setObjectName("label")
         self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
+        self.lblLabelValues = QtWidgets.QLabel(self.layoutWidget2)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
+        sizePolicy.setHorizontalStretch(0)
+        sizePolicy.setVerticalStretch(0)
+        sizePolicy.setHeightForWidth(self.lblLabelValues.sizePolicy().hasHeightForWidth())
+        self.lblLabelValues.setSizePolicy(sizePolicy)
+        self.lblLabelValues.setAlignment(QtCore.Qt.AlignCenter)
+        self.lblLabelValues.setObjectName("lblLabelValues")
+        self.gridLayout.addWidget(self.lblLabelValues, 0, 1, 1, 1)
+        self.btnAddMessagetype = QtWidgets.QToolButton(self.layoutWidget2)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
+        sizePolicy.setHorizontalStretch(0)
+        sizePolicy.setVerticalStretch(0)
+        sizePolicy.setHeightForWidth(self.btnAddMessagetype.sizePolicy().hasHeightForWidth())
+        self.btnAddMessagetype.setSizePolicy(sizePolicy)
+        icon = QtGui.QIcon.fromTheme("list-add")
+        self.btnAddMessagetype.setIcon(icon)
+        self.btnAddMessagetype.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
+        self.btnAddMessagetype.setObjectName("btnAddMessagetype")
+        self.gridLayout.addWidget(self.btnAddMessagetype, 3, 0, 1, 1)
         self.tblLabelValues = LabelValueTableView(self.layoutWidget2)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
@@ -541,26 +538,21 @@ class Ui_TabAnalysis(object):
         self.tblLabelValues.horizontalHeader().setDefaultSectionSize(150)
         self.tblLabelValues.horizontalHeader().setStretchLastSection(True)
         self.tblLabelValues.verticalHeader().setVisible(False)
-        self.gridLayout.addWidget(self.tblLabelValues, 1, 1, 2, 1)
-        self.lblLabelValues = QtWidgets.QLabel(self.layoutWidget2)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
-        sizePolicy.setHorizontalStretch(0)
-        sizePolicy.setVerticalStretch(0)
-        sizePolicy.setHeightForWidth(self.lblLabelValues.sizePolicy().hasHeightForWidth())
-        self.lblLabelValues.setSizePolicy(sizePolicy)
-        self.lblLabelValues.setAlignment(QtCore.Qt.AlignCenter)
-        self.lblLabelValues.setObjectName("lblLabelValues")
-        self.gridLayout.addWidget(self.lblLabelValues, 0, 1, 1, 1)
-        self.listViewLabelNames = ProtocolLabelListView(self.layoutWidget2)
+        self.gridLayout.addWidget(self.tblLabelValues, 1, 1, 3, 1)
+        self.tblViewMessageTypes = MessageTypeTableView(self.layoutWidget2)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
-        sizePolicy.setHeightForWidth(self.listViewLabelNames.sizePolicy().hasHeightForWidth())
-        self.listViewLabelNames.setSizePolicy(sizePolicy)
-        self.listViewLabelNames.setAcceptDrops(False)
-        self.listViewLabelNames.setFrameShape(QtWidgets.QFrame.StyledPanel)
-        self.listViewLabelNames.setObjectName("listViewLabelNames")
-        self.gridLayout.addWidget(self.listViewLabelNames, 2, 0, 1, 1)
+        sizePolicy.setHeightForWidth(self.tblViewMessageTypes.sizePolicy().hasHeightForWidth())
+        self.tblViewMessageTypes.setSizePolicy(sizePolicy)
+        self.tblViewMessageTypes.setAcceptDrops(False)
+        self.tblViewMessageTypes.setToolTip("")
+        self.tblViewMessageTypes.setFrameShape(QtWidgets.QFrame.StyledPanel)
+        self.tblViewMessageTypes.setAlternatingRowColors(True)
+        self.tblViewMessageTypes.setShowGrid(False)
+        self.tblViewMessageTypes.setObjectName("tblViewMessageTypes")
+        self.tblViewMessageTypes.verticalHeader().setVisible(False)
+        self.gridLayout.addWidget(self.tblViewMessageTypes, 1, 0, 2, 1)
         self.verticalLayout_4.addLayout(self.gridLayout)
         self.verticalLayout_5.addWidget(self.splitter_2)
         self.scrollArea.setWidget(self.scrollAreaWidgetContents)
@@ -575,34 +567,32 @@ class Ui_TabAnalysis(object):
         TabAnalysis.setWindowTitle(_translate("TabAnalysis", "Frame"))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_protocols), _translate("TabAnalysis", "Protocols"))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_participants), _translate("TabAnalysis", "Participants"))
+        self.label_5.setText(_translate("TabAnalysis", "Decoding:"))
         self.label_4.setText(_translate("TabAnalysis", "View data as:"))
-        self.cbProtoView.setToolTip(_translate("TabAnalysis", "<html><head/><body><p>Set the desired view here.</p></body></html>"))
-        self.cbProtoView.setItemText(0, _translate("TabAnalysis", "Bits"))
-        self.cbProtoView.setItemText(1, _translate("TabAnalysis", "Hex"))
-        self.cbProtoView.setItemText(2, _translate("TabAnalysis", "ASCII"))
-        self.label_5.setText(_translate("TabAnalysis", "Configure Decoding:"))
+        self.lEncodingErrors.setText(_translate("TabAnalysis", "Decoding errors:"))
         self.cbDecoding.setItemText(0, _translate("TabAnalysis", "NRZ"))
         self.cbDecoding.setItemText(1, _translate("TabAnalysis", "Manchester"))
         self.cbDecoding.setItemText(2, _translate("TabAnalysis", "Manchester II"))
         self.cbDecoding.setItemText(3, _translate("TabAnalysis", "Differential Manchester"))
         self.cbDecoding.setItemText(4, _translate("TabAnalysis", "..."))
-        self.lEncodingErrors.setText(_translate("TabAnalysis", "Decoding errors for message:"))
-        self.lDecodingErrorsValue.setText(_translate("TabAnalysis", "0 (0.00%)"))
-        self.cbShowDiffs.setText(_translate("TabAnalysis", "Mark diffs in protocol"))
         self.chkBoxShowOnlyDiffs.setText(_translate("TabAnalysis", "Show only diffs in protocol"))
+        self.cbProtoView.setToolTip(_translate("TabAnalysis", "<html><head/><body><p>Set the desired view here.</p></body></html>"))
+        self.cbProtoView.setItemText(0, _translate("TabAnalysis", "Bits"))
+        self.cbProtoView.setItemText(1, _translate("TabAnalysis", "Hex"))
+        self.cbProtoView.setItemText(2, _translate("TabAnalysis", "ASCII"))
+        self.lDecodingErrorsValue.setText(_translate("TabAnalysis", "0 (0.00%)"))
         self.chkBoxOnlyShowLabelsInProtocol.setText(_translate("TabAnalysis", "Show only labels in protocol"))
-        self.btnAnalyze.setText(_translate("TabAnalysis", "Analyze"))
+        self.cbShowDiffs.setText(_translate("TabAnalysis", "Mark diffs in protocol"))
+        self.btnAnalyze.setToolTip(_translate("TabAnalysis", "<html><head/><body><p>Run some automatic analysis on the protocol e.g. assign labels automatically. You can configure which checks to run with the arrow on the right of this button.</p></body></html>"))
+        self.btnAnalyze.setText(_translate("TabAnalysis", "Analyze Protocol"))
         self.btnSaveProto.setToolTip(_translate("TabAnalysis", "Save current protocol."))
-        self.label_2.setToolTip(_translate("TabAnalysis", "<html><head/><body><p>The <span style=\" font-weight:600;\">Received Signal Strength Indicator</span> indicates the average signal power of the current message.</p></body></html>"))
-        self.label_2.setText(_translate("TabAnalysis", "RSSI:"))
         self.lSlash.setText(_translate("TabAnalysis", "/"))
         self.lblShownRows.setText(_translate("TabAnalysis", "shown: 42/108"))
         self.lTime.setToolTip(_translate("TabAnalysis", "<html><head/><body><p>The <span style=\" font-weight:600;\">Message</span><span style=\" font-weight:600;\">Start</span> is the point in time when a protocol message begins. Additionally the relative time (+ ...) from the previous message is shown.</p></body></html>"))
         self.lTime.setText(_translate("TabAnalysis", "0 (+0)"))
         self.lSearchCurrent.setText(_translate("TabAnalysis", "-"))
-        self.lblRSSI.setToolTip(_translate("TabAnalysis", "<html><head/><body><p>The <span style=\" font-weight:600;\">Received Signal Strength Indicator</span> indicates the average signal power of the current message.</p></body></html>"))
-        self.lblRSSI.setText(_translate("TabAnalysis", "1.04"))
-        self.lineEditSearch.setPlaceholderText(_translate("TabAnalysis", "Enter pattern here"))
+        self.lblRSSI.setToolTip(_translate("TabAnalysis", "<html><head/><body><p>This is the average signal power of the current message. The nearer this value is to zero, the stronger the signal is.</p></body></html>"))
+        self.lblRSSI.setText(_translate("TabAnalysis", "-∞ dBm"))
         self.btnNextSearch.setText(_translate("TabAnalysis", ">"))
         self.btnPrevSearch.setText(_translate("TabAnalysis", "<"))
         self.lSearchTotal.setText(_translate("TabAnalysis", "-"))
@@ -612,23 +602,18 @@ class Ui_TabAnalysis(object):
         self.btnLoadProto.setToolTip(_translate("TabAnalysis", "Load a protocol."))
         self.btnLoadProto.setText(_translate("TabAnalysis", "..."))
         self.lblClearAlignment.setText(_translate("TabAnalysis", "<html><head/><body><p><a href=\"reset_alignment\"><span style=\" text-decoration: underline; color:#0000ff;\">Reset alignment</span></a></p></body></html>"))
+        self.lineEditSearch.setPlaceholderText(_translate("TabAnalysis", "Enter pattern here"))
         self.lBits.setText(_translate("TabAnalysis", "Bit:"))
         self.lHex.setText(_translate("TabAnalysis", "Hex:"))
         self.lDecimal.setText(_translate("TabAnalysis", "Decimal:"))
         self.lNumSelectedColumns.setText(_translate("TabAnalysis", "0"))
         self.lColumnsSelectedText.setText(_translate("TabAnalysis", "column(s) selected"))
-        self.btnMessagetypeSettings.setToolTip(_translate("TabAnalysis", "Settings for message type"))
-        self.btnMessagetypeSettings.setText(_translate("TabAnalysis", "..."))
+        self.label.setText(_translate("TabAnalysis", "Message types"))
+        self.lblLabelValues.setText(_translate("TabAnalysis", "Labels for message"))
         self.btnAddMessagetype.setToolTip(_translate("TabAnalysis", "Add a new message type"))
-        self.btnAddMessagetype.setText(_translate("TabAnalysis", "..."))
-        self.btnRemoveMessagetype.setToolTip(_translate("TabAnalysis", "Delete current message type"))
-        self.btnRemoveMessagetype.setText(_translate("TabAnalysis", "..."))
-        self.label.setText(_translate("TabAnalysis", "Message type:"))
-        self.lblLabelValues.setText(_translate("TabAnalysis", "Label values for message"))
-        self.listViewLabelNames.setToolTip(_translate("TabAnalysis", "Manage your estimations for protocol fields here. To add custom field types use Rightclick -> Edit."))
-
+        self.btnAddMessagetype.setText(_translate("TabAnalysis", "Add new message type"))
 from urh.ui.views.LabelValueTableView import LabelValueTableView
-from urh.ui.views.ProtocolLabelListView import ProtocolLabelListView
+from urh.ui.views.MessageTypeTableView import MessageTypeTableView
 from urh.ui.views.ProtocolTableView import ProtocolTableView
 from urh.ui.views.ProtocolTreeView import ProtocolTreeView
 from . import urh_rc
