@@ -8,28 +8,53 @@ import numpy as np
 from PyQt5.QtCore import QDir
 from PyQt5.QtWidgets import QFileDialog, QMessageBox
 
-from urh.models.FileIconProvider import FileIconProvider
 from urh.signalprocessing.IQArray import IQArray
 
-VIEW_TYPES = ["Bits", "Hex", "ASCII"]
-
 archives = {}
 """:type: dict of [str, str]
    :param: archives[extracted_filename] = filename"""
 
 RECENT_PATH = QDir.homePath()
 
-EXT = {np.int8: ".complex16s", np.uint8: ".complex16u", np.int16: ".complex32s", np.uint16: ".complex32u",
-       np.float32: ".complex", np.complex64: ".complex"}
-FILTER = {np.int8: "Complex16 signed (*.complex16s *.cs8)", np.uint8: "Complex16 unsigned (*.complex16u *.cu8)",
-          np.uint16: "Complex32 unsigned (*.complex32u *.cu16)", np.int16: "Complex32 signed (*.complex32s *.cs16)",
-          np.float32: "Complex (*.complex)", np.complex64: "Complex (*.complex)"}
+SIGNAL_FILE_EXTENSIONS_BY_TYPE = {
+    np.int8: ".complex16s",
+    np.uint8: ".complex16u",
+    np.int16: ".complex32s",
+    np.uint16: ".complex32u",
+    np.float32: ".complex",
+    np.complex64: ".complex"
+}
+
+SIGNAL_NAME_FILTERS_BY_TYPE = {
+    np.int8: "Complex16 signed (*.complex16s *.cs8)",
+    np.uint8: "Complex16 unsigned (*.complex16u *.cu8)",
+    np.uint16: "Complex32 unsigned (*.complex32u *.cu16)",
+    np.int16: "Complex32 signed (*.complex32s *.cs16)",
+    np.float32: "Complex (*.complex)",
+    np.complex64: "Complex (*.complex)"
+}
+
+EVERYTHING_FILE_FILTER = "All Files (*)"
+
+SIGNAL_NAME_FILTERS = list(sorted(set(SIGNAL_NAME_FILTERS_BY_TYPE.values())))
+
+COMPRESSED_COMPLEX_FILE_FILTER = "Compressed Complex File (*.coco)"
+WAV_FILE_FILTER = "Waveform Audio File Format (*.wav *.wave)"
+PROTOCOL_FILE_FILTER = "Protocol (*.proto.xml *.proto)"
+BINARY_PROTOCOL_FILE_FILTER = "Binary Protocol (*.bin)"
+PLAIN_BITS_FILE_FILTER = "Plain Bits (*.txt)"
+FUZZING_FILE_FILTER = "Fuzzing Profile (*.fuzz.xml *.fuzz)"
+SIMULATOR_FILE_FILTER = "Simulator Profile (*.sim.xml *.sim)"
+TAR_FILE_FILTER = "Tar Archive (*.tar *.tar.gz *.tar.bz2)"
+ZIP_FILE_FILTER = "Zip Archive (*.zip)"
+
+
+def __get__name_filter_for_signals() -> str:
+    return ";;".join([EVERYTHING_FILE_FILTER] + SIGNAL_NAME_FILTERS + [COMPRESSED_COMPLEX_FILE_FILTER, WAV_FILE_FILTER])
 
 
 def get_open_dialog(directory_mode=False, parent=None, name_filter="full") -> QFileDialog:
-    fip = FileIconProvider()
     dialog = QFileDialog(parent=parent, directory=RECENT_PATH)
-    dialog.setIconProvider(fip)
 
     if directory_mode:
         dialog.setFileMode(QFileDialog.Directory)
@@ -38,98 +63,45 @@ def get_open_dialog(directory_mode=False, parent=None, name_filter="full") -> QF
         dialog.setFileMode(QFileDialog.ExistingFiles)
         dialog.setWindowTitle("Open Files")
         if name_filter == "full":
-            name_filter = "All Files (*);;" \
-                          "Complex (*.complex);;" \
-                          "Complex16 unsigned (*.complex16u *.cu8);;" \
-                          "Complex16 signed (*.complex16s *.cs8);;" \
-                          "Complex32 unsigned (*.complex32u *.cu16);;" \
-                          "Complex32 signed (*.complex32s *.cs16);;" \
-                          "WAV (*.wav);;" \
-                          "Protocols (*.proto.xml *.proto);;" \
-                          "Binary Protocols (*.bin);;" \
-                          "Fuzzing Profiles (*.fuzz.xml *.fuzz);;" \
-                          "Simulator (*.sim.xml *.sim)" \
-                          "Plain Bits (*.txt);;" \
-                          "Tar Archives (*.tar *.tar.gz *.tar.bz2);;" \
-                          "Zip Archives (*.zip)"
+            name_filter = __get__name_filter_for_signals() + ";;" \
+                          + ";;".join([PROTOCOL_FILE_FILTER, BINARY_PROTOCOL_FILE_FILTER, PLAIN_BITS_FILE_FILTER,
+                                       FUZZING_FILE_FILTER, SIMULATOR_FILE_FILTER, TAR_FILE_FILTER, ZIP_FILE_FILTER])
+        elif name_filter == "signals_only":
+            name_filter = __get__name_filter_for_signals()
         elif name_filter == "proto":
-            name_filter = "Protocols (*.proto.xml *.proto);; Binary Protocols (*.bin)"
+            name_filter = ";;".join([PROTOCOL_FILE_FILTER, BINARY_PROTOCOL_FILE_FILTER])
         elif name_filter == "fuzz":
-            name_filter = "Fuzzprofiles (*.fuzz.xml *.fuzz)"
+            name_filter = FUZZING_FILE_FILTER
         elif name_filter == "simulator":
-            name_filter = "Simulator (*.sim.xml *.sim)"
+            name_filter = SIMULATOR_FILE_FILTER
 
         dialog.setNameFilter(name_filter)
 
-    dialog.setOptions(QFileDialog.DontResolveSymlinks)
-    dialog.setViewMode(QFileDialog.Detail)
-
     return dialog
 
 
-def uncompress_archives(file_names, temp_dir):
-    """
-    Extract each archive from the list of filenames.
-    Normal files stay untouched.
-    Add all files to the Recent Files.
-    :type file_names: list of str
-    :type temp_dir: str
-    :rtype: list of str
-    """
-    result = []
-    for filename in file_names:
-        if filename.endswith(".tar") or filename.endswith(".tar.gz") or filename.endswith(".tar.bz2"):
-            obj = tarfile.open(filename, "r")
-            extracted_file_names = []
-            for j, member in enumerate(obj.getmembers()):
-                obj.extract(member, temp_dir)
-                extracted_filename = os.path.join(temp_dir, obj.getnames()[j])
-                extracted_file_names.append(extracted_filename)
-                archives[extracted_filename] = filename
-            result.extend(extracted_file_names[:])
-        elif filename.endswith(".zip"):
-            obj = zipfile.ZipFile(filename)
-            extracted_file_names = []
-            for j, info in enumerate(obj.infolist()):
-                obj.extract(info, path=temp_dir)
-                extracted_filename = os.path.join(temp_dir, obj.namelist()[j])
-                extracted_file_names.append(extracted_filename)
-                archives[extracted_filename] = filename
-            result.extend(extracted_file_names[:])
-        else:
-            result.append(filename)
-
-    return result
-
-
-def get_save_file_name(initial_name: str, wav_only=False, caption="Save signal", selected_name_filter=None):
+def ask_save_file_name(initial_name: str, caption="Save signal", selected_name_filter=None):
     global RECENT_PATH
     if caption == "Save signal":
-        name_filter = "Complex (*.complex);;" \
-                      "Complex16 unsigned (*.complex16u *.cu8);;" \
-                      "Complex16 signed (*.complex16s *.cs8);;" \
-                      "Complex32 unsigned (*.complex32u *.cu16);;" \
-                      "Complex32 signed (*.complex32s *.cs16);;" \
-                      "Complex compressed (*.coco);;" \
-                      "WAV (*.wav);;" \
-                      "All Files (*)"
-        if wav_only:
-            name_filter = "WAV (*.wav);;All Files (*)"
-    elif caption == "Save fuzz profile":
-        name_filter = "Fuzzing Profile (*.fuzz.xml *.fuzz);;All Files (*)"
+        name_filter = __get__name_filter_for_signals()
+    elif caption == "Save fuzzing profile":
+        name_filter = FUZZING_FILE_FILTER
     elif caption == "Save encoding":
         name_filter = ""
     elif caption == "Save simulator profile":
-        name_filter = "Simulator (*.sim.xml *.sim);;All Files (*)"
+        name_filter = SIMULATOR_FILE_FILTER
     elif caption == "Export spectrogram":
         name_filter = "Frequency Time (*.ft);;Frequency Time Amplitude (*.fta)"
+    elif caption == "Save protocol":
+        name_filter = ";;".join([PROTOCOL_FILE_FILTER, BINARY_PROTOCOL_FILE_FILTER])
+    elif caption == "Export demodulated":
+        name_filter = WAV_FILE_FILTER
     else:
-        name_filter = "Protocols (*.proto.xml *.proto);;Binary Protocol (*.bin);;All Files (*)"
+        name_filter = EVERYTHING_FILE_FILTER
 
     filename = None
     dialog = QFileDialog(directory=RECENT_PATH, caption=caption, filter=name_filter)
     dialog.setFileMode(QFileDialog.AnyFile)
-    dialog.setViewMode(QFileDialog.Detail)
     dialog.setLabelText(QFileDialog.Accept, "Save")
     dialog.setAcceptMode(QFileDialog.AcceptSave)
 
@@ -147,23 +119,23 @@ def get_save_file_name(initial_name: str, wav_only=False, caption="Save signal",
     return filename
 
 
-def save_data_dialog(signal_name: str, data, sample_rate=1e6, wav_only=False, parent=None) -> str:
+def ask_signal_file_name_and_save(signal_name: str, data, sample_rate=1e6, wav_only=False, parent=None) -> str:
     if wav_only:
-        if not signal_name.endswith(".wav"):
+        if not signal_name.endswith(".wav") and not signal_name.endswith(".wave"):
             signal_name += ".wav"
-        name_filter = "WAV (*.wav)"
+        selected_name_filter = WAV_FILE_FILTER
     else:
-        if not any(signal_name.endswith(e) for e in FILTER.values()):
+        if not any(signal_name.endswith(e) for e in SIGNAL_NAME_FILTERS_BY_TYPE.values()):
             try:
-                dtype = next(d for d in EXT.keys() if d == data.dtype)
-                signal_name += EXT[dtype]
-                name_filter = FILTER[dtype]
+                dtype = next(d for d in SIGNAL_FILE_EXTENSIONS_BY_TYPE.keys() if d == data.dtype)
+                signal_name += SIGNAL_FILE_EXTENSIONS_BY_TYPE[dtype]
+                selected_name_filter = SIGNAL_NAME_FILTERS_BY_TYPE[dtype]
             except StopIteration:
-                name_filter = None
+                selected_name_filter = None
         else:
-            name_filter = None
+            selected_name_filter = None
 
-    filename = get_save_file_name(signal_name, wav_only, selected_name_filter=name_filter)
+    filename = ask_save_file_name(signal_name, selected_name_filter=selected_name_filter)
 
     if filename:
         try:
@@ -232,6 +204,41 @@ def rewrite_tar(tar_name: str):
         shutil.rmtree(tempdir)
 
 
+def uncompress_archives(file_names, temp_dir):
+    """
+    Extract each archive from the list of filenames.
+    Normal files stay untouched.
+    Add all files to the Recent Files.
+    :type file_names: list of str
+    :type temp_dir: str
+    :rtype: list of str
+    """
+    result = []
+    for filename in file_names:
+        if filename.endswith(".tar") or filename.endswith(".tar.gz") or filename.endswith(".tar.bz2"):
+            obj = tarfile.open(filename, "r")
+            extracted_file_names = []
+            for j, member in enumerate(obj.getmembers()):
+                obj.extract(member, temp_dir)
+                extracted_filename = os.path.join(temp_dir, obj.getnames()[j])
+                extracted_file_names.append(extracted_filename)
+                archives[extracted_filename] = filename
+            result.extend(extracted_file_names[:])
+        elif filename.endswith(".zip"):
+            obj = zipfile.ZipFile(filename)
+            extracted_file_names = []
+            for j, info in enumerate(obj.infolist()):
+                obj.extract(info, path=temp_dir)
+                extracted_filename = os.path.join(temp_dir, obj.namelist()[j])
+                extracted_file_names.append(extracted_filename)
+                archives[extracted_filename] = filename
+            result.extend(extracted_file_names[:])
+        else:
+            result.append(filename)
+
+    return result
+
+
 def get_directory():
     directory = QFileDialog.getExistingDirectory(None, "Choose Directory", QDir.homePath(),
                                                  QFileDialog.ShowDirsOnly | QFileDialog.DontResolveSymlinks)
